==> brmo-stufbg204-1.6.3p1-sources.jar: nl/egem/stuf/stuf0204/StUFBerichtenSet.java <==

package nl.egem.stuf.stuf0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlElementRefs;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="unbounded" minOccurs="0">
 *         &lt;choice>
 *           &lt;element name="kennisgevingsBericht" type="{http://www.w3.org/2001/XMLSchema}anyType"/>
 *           &lt;element name="vraagBericht" type="{http://www.w3.org/2001/XMLSchema}anyType"/>
 *           &lt;element name="asynchroonAntwoordBericht" type="{http://www.w3.org/2001/XMLSchema}anyType"/>
 *           &lt;element ref="{http://www.egem.nl/StUF/StUF0204}foutBericht"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht"
})
@XmlRootElement(name = "StUF-berichtenSet")
public class StUFBerichtenSet {

    @XmlElementRefs({
        @XmlElementRef(name = "kennisgevingsBericht", namespace = "http://www.egem.nl/StUF/StUF0204", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "asynchroonAntwoordBericht", namespace = "http://www.egem.nl/StUF/StUF0204", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "foutBericht", namespace = "http://www.egem.nl/StUF/StUF0204", type = FoutBericht.class, required = false),
        @XmlElementRef(name = "vraagBericht", namespace = "http://www.egem.nl/StUF/StUF0204", type = JAXBElement.class, required = false)
    })
    protected List<Object> kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht;

    /**
     * Gets the value of the kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getKennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link JAXBElement }{@code <}{@link Object }{@code >}
     * {@link JAXBElement }{@code <}{@link Object }{@code >}
     * {@link JAXBElement }{@code <}{@link Object }{@code >}
     * {@link FoutBericht }
     * 
     * 
     */
    public List<Object> getKennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht() {
        if (kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht == null) {
            kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht = new ArrayList<Object>();
        }
        return this.kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht;
    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/stuf0204/StUFBerichtenSet.java <==

package nl.egem.stuf.stuf0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlElementRefs;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence maxOccurs="unbounded" minOccurs="0"&gt;
 *         &lt;choice&gt;
 *           &lt;element name="kennisgevingsBericht" type="{http://www.w3.org/2001/XMLSchema}anyType"/&gt;
 *           &lt;element name="vraagBericht" type="{http://www.w3.org/2001/XMLSchema}anyType"/&gt;
 *           &lt;element name="asynchroonAntwoordBericht" type="{http://www.w3.org/2001/XMLSchema}anyType"/&gt;
 *           &lt;element ref="{http://www.egem.nl/StUF/StUF0204}foutBericht"/&gt;
 *         &lt;/choice&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht"
})
@XmlRootElement(name = "StUF-berichtenSet")
public class StUFBerichtenSet {

    @XmlElementRefs({
        @XmlElementRef(name = "kennisgevingsBericht", namespace = "http://www.egem.nl/StUF/StUF0204", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "vraagBericht", namespace = "http://www.egem.nl/StUF/StUF0204", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "asynchroonAntwoordBericht", namespace = "http://www.egem.nl/StUF/StUF0204", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "foutBericht", namespace = "http://www.egem.nl/StUF/StUF0204", type = FoutBericht.class, required = false)
    })
    protected List<Object> kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht;

    /**
     * Gets the value of the kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getKennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link JAXBElement }{@code <}{@link Object }{@code >}
     * {@link JAXBElement }{@code <}{@link Object }{@code >}
     * {@link JAXBElement }{@code <}{@link Object }{@code >}
     * {@link FoutBericht }
     * 
     * 
     */
    public List<Object> getKennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht() {
        if (kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht == null) {
            kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht = new ArrayList<Object>();
        }
        return this.kennisgevingsBerichtOrVraagBerichtOrAsynchroonAntwoordBericht;
    }

}
